==> webmeter-core-1.0.11-10.jar: webmeter/sqls/publics/businessV1/getSetPrice.sql <==
-- 公共SQL：生成调价指令（适用V1，用于直接使用气价明细调价的情况）
-- 必选参数
-- f_meter_brand：表具品牌别名
-- setPriceSync：调价记录同步状态字段

SELECT
    -- 业务记录ID
    setinfo.id,
    -- 表档案ID
    setinfo.userid,
    -- 表号
    setinfo.f_meternumber,
    -- 卡号
    setinfo.f_card_id,
    -- 气价ID
    setinfo.stairid,
    -- 旧气价ID
    setinfo.oldstairid,
    -- 阶梯开始时间
    setinfo.start_date,
    -- 价格生效时间
    setinfo.f_perform_date,
    -- 阶梯周期（月）
    setinfo.f_stairmonths,
    -- 是否采暖气价
    setinfo.f_isheat,
    -- 调价类型
    setinfo.type,
    -- 价格版本
    setinfo.priceversion,
    -- 结算类型（按金额，按气量）
    setinfo.f_collection_type
FROM (
    SELECT p.id                                           id,
           u.f_user_id                                    userid,
           u.f_meternumber,
           ISNULL(u.f_card_id, u.f_meternumber)           f_card_id,
           s.id                                           stairId,
           p.f_oldprice_id                                oldstairid,
           ISNULL(s.f_version, 1)                         priceversion,
           ISNULL(s.f_stair_start_date, s.f_perform_date) start_date,
           p.f_perform_date                               f_perform_date,
           ISNULL(s.f_stairmonths, 1)                     f_stairmonths,
           0 f_isheat,
           g.f_collection_type,
           '批量调价'                                      type
    FROM t_pricechange p
        LEFT JOIN t_stairprice s ON s.id = p.f_newprice_id
        INNER JOIN t_userfiles u ON u.f_price_id = s.f_price_id
        LEFT JOIN t_gasbrand g ON u.f_gasbrand_id = g.id
    WHERE s.f_state = '有效'
      AND getdate() >= s.f_perform_date
      and getdate() <= s.f_end_date
      AND (p.${setPriceSync} IS NULL or p.${setPriceSync} = '未同步')
      AND p.f_change_type = '批量'
      AND u.f_sendsuccess = '成功'
      AND u.f_table_state = '正常'
      AND g.f_alias = '{f_meter_brand}'
    UNION ALL
    SELECT p.id                                           id,
           u.f_user_id                                    userid,
           u.f_meternumber,
           ISNULL(u.f_card_id, u.f_meternumber)           f_card_id,
           s.id                                           stairId,
           p.f_oldprice_id                                oldstairid,
           ISNULL(s.f_version, 1)                         priceversion,
           ISNULL(s.f_stair_start_date, s.f_perform_date) start_date,
           p.f_perform_date                               f_perform_date,
           ISNULL(s.f_stairmonths, 1)                     f_stairmonths,
           0 f_isheat,
           g.f_collection_type,
           '单表调价'                                      type
    FROM t_pricechange p
        INNER JOIN t_userfiles u ON cast(u.f_userinfo_id as varchar) = p.f_userinfo_id
        LEFT JOIN t_gasbrand g ON u.f_gasbrand_id = g.id
        LEFT JOIN t_stairprice s ON s.id = p.f_newprice_id
    WHERE s.f_state = '有效'
      AND getdate() >= s.f_perform_date
      and getdate() <= s.f_end_date
      AND (p.${setPriceSync} IS NULL or p.${setPriceSync} = '未同步')
      AND p.f_change_type = '单户'
      AND u.f_sendsuccess = '成功'
      AND u.f_table_state = '正常'
      AND g.f_alias = '{f_meter_brand}'
     ) setinfo

==> webmeter-core-1.0.18-rc8.jar: webmeter/sqls/publics/businessV1/getSetPrice.sql <==
-- 公共SQL：生成调价指令（适用V1，用于直接使用气价明细调价的情况）
-- 必选参数
-- f_meter_brand：表具品牌别名
-- setPriceSync：调价记录同步状态字段

SELECT
    -- 业务记录ID
    setinfo.id,
    -- 表档案ID
    setinfo.userid,
    -- 表号
    setinfo.f_meternumber,
    -- 卡号
    setinfo.f_card_id,
    -- 气价ID
    setinfo.stairid,
    -- 旧气价ID
    setinfo.oldstairid,
    -- 阶梯开始时间
    setinfo.start_date,
    -- 价格生效时间
    setinfo.f_perform_date,
    -- 阶梯周期（月）
    setinfo.f_stairmonths,
    -- 是否采暖气价
    setinfo.f_isheat,
    -- 调价类型
    setinfo.type,
    -- 价格版本
    setinfo.priceversion,
    -- 结算类型（按金额，按气量）
    setinfo.f_collection_type
FROM (
    SELECT p.id                                           id,
           u.f_user_id                                    userid,
           u.f_meternumber,
           ISNULL(u.f_card_id, u.f_meternumber)           f_card_id,
           s.id                                           stairId,
           p.f_oldprice_id                                oldstairid,
           s.f_version + u.f_price_version                priceversion,
           ISNULL(s.f_stair_start_date, s.f_perform_date) start_date,
           p.f_perform_date                               f_perform_date,
           ISNULL(s.f_stairmonths, 1)                     f_stairmonths,
           0 f_isheat,
           g.f_collection_type,
           '批量调价'                                      type
    FROM t_pricechange p
        LEFT JOIN t_stairprice s ON s.id = p.f_newprice_id
        INNER JOIN t_userfiles u ON u.f_price_id = s.f_price_id
        LEFT JOIN t_gasbrand g ON u.f_gasbrand_id = g.id
    WHERE s.f_state = '有效'
      AND getdate() >= s.f_perform_date
      and getdate() <= s.f_end_date
      AND (p.${setPriceSync} IS NULL or p.${setPriceSync} = '未同步')
      AND p.f_change_type = '批量'
      AND u.f_sendsuccess = '成功'
      AND u.f_table_state = '正常'
      AND g.f_alias = '{f_meter_brand}'
    UNION ALL
    SELECT p.id                                           id,
           u.f_user_id                                    userid,
           u.f_meternumber,
           ISNULL(u.f_card_id, u.f_meternumber)           f_card_id,
           s.id                                           stairId,
           p.f_oldprice_id                                oldstairid,
           s.f_version + u.f_price_version                priceversion,
           ISNULL(s.f_stair_start_date, s.f_perform_date) start_date,
           p.f_perform_date                               f_perform_date,
           ISNULL(s.f_stairmonths, 1)                     f_stairmonths,
           0 f_isheat,
           g.f_collection_type,
           '单表调价'                                      type
    FROM t_pricechange p
        INNER JOIN t_userfiles u ON cast(u.f_userinfo_id as varchar) = p.f_userinfo_id
        LEFT JOIN t_gasbrand g ON u.f_gasbrand_id = g.id
        LEFT JOIN t_stairprice s ON s.id = p.f_newprice_id
    WHERE s.f_state = '有效'
      AND getdate() >= s.f_perform_date
      and getdate() <= s.f_end_date
      AND (p.${setPriceSync} IS NULL or p.${setPriceSync} = '未同步')
      AND p.f_change_type = '单户'
      AND u.f_sendsuccess = '成功'
      AND u.f_table_state = '正常'
      AND g.f_alias = '{f_meter_brand}'
     ) setinfo
